This page is a work in progress, its purpose is to provide an overview of the relevant parts of *kiara*, as well as
links to further information.

## Basics

- [Getting started](https://dharpa.org/kiara.documentation/latest/usage/getting_started/): A quick (end-user) introduction to *kiara*.

### Install a development environment

- [install dev env](install.md)

### Create a *kiara* plugin package

- [`kiara_plugin.develop repo`](https://github.com/DHARPA-Project/kiara_plugin.develop)

### Create a *kiara* module

- [create module](https://dharpa.org/kiara.documentation/latest/extending_kiara/creating_modules/the_basics/)

### Creeae a *kiara* pipeline

- [create pipeline](https://dharpa.org/kiara.documentation/latest/extending_kiara/pipelines/assemble_pipelines/)
